pub enum SortOrder {
Default,
Upper,
Lower,
Unicode,
}Expand description
Controls the lexicographic sorting of file and folder names.
Variants
Default
Case-insensitive natural sort with lowercase preferred in ties.
Numbers in file names are compared by value (e.g., file2 before file10).
Upper
Uppercase names are grouped before lowercase names, with case-insensitive natural sort within each group. Dot-prefixed names sort before both groups.
Lower
Lowercase names are grouped before uppercase names, with case-insensitive natural sort within each group. Dot-prefixed names sort before both groups.
Unicode
Pure Unicode codepoint comparison. No case folding, no natural number sorting. Uppercase ASCII sorts before lowercase. Accented characters sort after ASCII.