Child

Struct Child 

pub struct Child { /* private fields */ }
A wrapper around smol::process::Child that ensures all subprocesses are killed when the process is terminated by using process groups.

Implementations

Source

impl Child

pub fn spawn( command: Command, stdin: Stdio, stdout: Stdio, stderr: Stdio, ) -> Result<Self>

pub fn into_inner(self) -> Child

pub fn kill(&mut self) -> Result<()>

Methods from Deref<Target = Child>

pub fn id(&self) -> u32

Returns the OS-assigned process identifier associated with this child.

Examples
use async_process::Command;

let mut child = Command::new("ls").spawn()?;
println!("id: {}", child.id());
pub fn kill(&mut self) -> Result<(), Error>

Forces the child process to exit.

If the child has already exited, an InvalidInput error is returned.

This is equivalent to sending a SIGKILL on Unix platforms.

Examples
use async_process::Command;

let mut child = Command::new("yes").spawn()?;
child.kill()?;
println!("exit status: {}", child.status().await?);
pub fn try_status(&mut self) -> Result<Option<ExitStatus>, Error>

Returns the exit status if the process has exited.

Unlike status(), this method will not drop the stdin handle.

Examples
use async_process::Command;

let mut child = Command::new("ls").spawn()?;

match child.try_status()? {
    None => println!("still running"),
    Some(status) => println!("exited with: {}", status),
}
pub fn status(&mut self) -> impl Future<Output = Result<ExitStatus, Error>>

Drops the stdin handle and waits for the process to exit.

Closing the stdin of the process helps avoid deadlocks. It ensures that the process does not block waiting for input from the parent process while the parent waits for the child to exit.

Examples
use async_process::{Command, Stdio};

let mut child = Command::new("cp")
    .arg("a.txt")
    .arg("b.txt")
    .spawn()?;

println!("exit status: {}", child.status().await?);