RelPathBuf

Struct RelPathBuf 

pub struct RelPathBuf(/* private fields */);
An owned representation of a file system path that is guaranteed to be relative and normalized.

This type is to RelPath as std::path::PathBuf is to std::path::Path

Implementations

Source

impl RelPathBuf

pub fn new() -> Self

pub fn pop(&mut self) -> bool

pub fn push(&mut self, path: &RelPath)

pub fn as_rel_path(&self) -> &RelPath

pub fn set_extension(&mut self, extension: &str) -> bool

Methods from Deref<Target = RelPath>

pub fn is_empty(&self) -> bool

pub fn components(&self) -> RelPathComponents<'_>

pub fn ancestors(&self) -> RelPathAncestors<'_>

pub fn file_name(&self) -> Option<&str>

pub fn file_stem(&self) -> Option<&str>

pub fn extension(&self) -> Option<&str>

pub fn parent(&self) -> Option<&Self>

pub fn starts_with(&self, other: &Self) -> bool

pub fn ends_with(&self, other: &Self) -> bool

pub fn strip_prefix<'a>( &'a self, other: &Self, ) -> Result<&'a Self, StripPrefixError>

pub fn len(&self) -> usize

pub fn last_n_components(&self, count: usize) -> Option<&Self>

pub fn join(&self, other: &Self) -> Arc<Self>

pub fn to_rel_path_buf(&self) -> RelPathBuf

pub fn into_arc(&self) -> Arc<Self>

pub fn to_proto(&self) -> String

Convert the path into the wire representation.

pub fn display(&self, style: PathStyle) -> Cow<'_, str>

Convert the path into a string with the given path style.

Whenever a path is presented to the user, it should be converted to a string via this method.

pub fn as_unix_str(&self) -> &str

Get the internal unix-style representation of the path.

This should not be shown to the user.

pub fn as_std_path(&self) -> &Path

Interprets the path as a std::path::Path, suitable for file system calls.

This is guaranteed to be a valid path regardless of the host platform, because the / is accepted as a path separator on windows.

This should not be shown to the user.