ShellBuilder

Struct ShellBuilder 

pub struct ShellBuilder { /* private fields */ }
ShellBuilder is used to turn a user-requested task into a program that can be executed by the shell.

Implementations

Source

impl ShellBuilder

pub fn new(shell: &Shell, is_windows: bool) -> Self

Create a new ShellBuilder as configured.

pub fn non_interactive(self) -> Self

pub fn command_label(&self, command_to_use_in_label: &str) -> String

Returns the label to show in the terminal tab

pub fn redirect_stdin_to_dev_null(self) -> Self

pub fn build( self, task_command: Option<String>, task_args: &[String], ) -> (String, Vec<String>)

Returns the program and arguments to run this task in a shell.

pub fn build_smol_command( self, task_command: Option<String>, task_args: &[String], ) -> Command

Builds a smol::process::Command with the given task command and arguments.

Prefer this over manually constructing a command with the output of Self::build, as this method handles cmd weirdness on windows correctly.

pub fn build_std_command( self, task_command: Option<String>, task_args: &[String], ) -> Command

Builds a std::process::Command with the given task command and arguments.

Prefer this over manually constructing a command with the output of Self::build, as this method handles cmd weirdness on windows correctly.

pub fn kind(&self) -> ShellKind