pub struct NumericPrefixWithSuffix<'a>(/* private fields */);Expand description
A way to sort strings with starting numbers numerically first, falling back to alphanumeric one, case-insensitive.
This is useful for turning regular alphanumerically sorted sequences as 1-abc, 10, 11-def, .., 2, 21-abc
into 1-abc, 2, 10, 11-def, .., 21-abc
Implementations
Sourceimpl<'a> NumericPrefixWithSuffix<'a>
impl<'a> NumericPrefixWithSuffix<'a>
pub fn from_numeric_prefixed_str(str: &'a str) -> Self