pub struct PathList { /* private fields */ }Expand description
A list of absolute paths, with an associated display order.
Two PathList values are considered equal if they contain the same paths,
regardless of the order in which those paths were originally provided.
The paths can be retrieved in the original order using ordered_paths().
Implementations
Sourceimpl PathList
impl PathList
pub fn new<P: AsRef<Path>>(paths: &[P]) -> Self
pub fn is_empty(&self) -> bool
Sourcepub fn without_path(&self, path_to_remove: &Path) -> PathList
pub fn without_path(&self, path_to_remove: &Path) -> PathList
Returns a new PathList with the given path removed.
Sourcepub fn paths_owned(&self) -> Arc<[PathBuf]>
pub fn paths_owned(&self) -> Arc<[PathBuf]>
Get the paths in the lexicographic order.
Sourcepub fn ordered_paths(&self) -> impl Iterator<Item = &PathBuf>
pub fn ordered_paths(&self) -> impl Iterator<Item = &PathBuf>
Get the paths in the original order.
pub fn is_lexicographically_ordered(&self) -> bool
pub fn deserialize(serialized: &SerializedPathList) -> Self
pub fn serialize(&self) -> SerializedPathList