pub trait UrlExt {
// Required method
fn to_file_path_ext(&self, path_style: PathStyle) -> Result<PathBuf, ()>;
}Required Methods
Sourcefn to_file_path_ext(&self, path_style: PathStyle) -> Result<PathBuf, ()>
fn to_file_path_ext(&self, path_style: PathStyle) -> Result<PathBuf, ()>
A version of url::Url::to_file_path that does platform handling based on the provided PathStyle instead of the host platform.
Prefer using this over url::Url::to_file_path when you need to handle paths in a cross-platform way as is the case for remoting interactions.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".