pub struct ShellBuilder { /* private fields */ }Expand description
ShellBuilder is used to turn a user-requested task into a program that can be executed by the shell.
Implementations
Sourceimpl ShellBuilder
impl ShellBuilder
pub fn non_interactive(self) -> Self
Sourcepub fn command_label(&self, command_to_use_in_label: &str) -> String
pub fn command_label(&self, command_to_use_in_label: &str) -> String
Returns the label to show in the terminal tab
pub fn redirect_stdin_to_dev_null(self) -> Self
Sourcepub fn build(
self,
task_command: Option<String>,
task_args: &[String],
) -> (String, Vec<String>)
pub fn build( self, task_command: Option<String>, task_args: &[String], ) -> (String, Vec<String>)
Returns the program and arguments to run this task in a shell.
Sourcepub fn build_smol_command(
self,
task_command: Option<String>,
task_args: &[String],
) -> Command
pub fn build_smol_command( self, task_command: Option<String>, task_args: &[String], ) -> Command
Builds a smol::process::Command with the given task command and arguments.
Prefer this over manually constructing a command with the output of Self::build,
as this method handles cmd weirdness on windows correctly.
Sourcepub fn build_std_command(
self,
task_command: Option<String>,
task_args: &[String],
) -> Command
pub fn build_std_command( self, task_command: Option<String>, task_args: &[String], ) -> Command
Builds a std::process::Command with the given task command and arguments.
Prefer this over manually constructing a command with the output of Self::build,
as this method handles cmd weirdness on windows correctly.
pub fn kind(&self) -> ShellKind